pub struct CreateNamespaceRequest {
pub kind: i32,
pub slug: String,
pub parent_path: String,
pub display_name: String,
pub client_operation_id: String,
}Fields
kind: i32slug: Stringparent_path: Stringdisplay_name: Stringclient_operation_id: StringIdempotency (audit-idempotency enforces tag 15).
Implementations
Sourceimpl CreateNamespaceRequest
impl CreateNamespaceRequest
Sourcepub fn kind(&self) -> NamespaceKind
pub fn kind(&self) -> NamespaceKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: NamespaceKind)
pub fn set_kind(&mut self, value: NamespaceKind)
Sets kind to the provided enum value.