pub struct QueryOperationsRequest {
pub repo_path: String,
pub actor: String,
pub symbol: String,
pub signal_kind: String,
pub thread: String,
pub verbs: Vec<String>,
pub since_secs: i64,
pub until_secs: i64,
pub limit: u32,
pub include_checkpoints: bool,
}Fields
repo_path: Stringactor: Stringsymbol: Stringsignal_kind: Stringthread: Stringverbs: Vec<String>since_secs: i64until_secs: i64limit: u32include_checkpoints: boolTrait Implementations
Sourceimpl Clone for QueryOperationsRequest
impl Clone for QueryOperationsRequest
Sourcefn clone(&self) -> QueryOperationsRequest
fn clone(&self) -> QueryOperationsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryOperationsRequest
impl Debug for QueryOperationsRequest
Sourceimpl Default for QueryOperationsRequest
impl Default for QueryOperationsRequest
Sourceimpl Hash for QueryOperationsRequest
impl Hash for QueryOperationsRequest
Sourceimpl Message for QueryOperationsRequest
impl Message for QueryOperationsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for QueryOperationsRequest
impl PartialEq for QueryOperationsRequest
Sourcefn eq(&self, other: &QueryOperationsRequest) -> bool
fn eq(&self, other: &QueryOperationsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for QueryOperationsRequest
impl StructuralPartialEq for QueryOperationsRequest