pub struct StoreProviderTokenRequest {
pub provider: String,
pub access_token: String,
pub refresh_token: String,
pub token_scope: String,
pub expires_at: Option<Timestamp>,
}Fields
provider: Stringaccess_token: Stringrefresh_token: Stringtoken_scope: Stringexpires_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for StoreProviderTokenRequest
impl Clone for StoreProviderTokenRequest
Sourcefn clone(&self) -> StoreProviderTokenRequest
fn clone(&self) -> StoreProviderTokenRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoreProviderTokenRequest
impl Debug for StoreProviderTokenRequest
Sourceimpl Default for StoreProviderTokenRequest
impl Default for StoreProviderTokenRequest
Sourceimpl Hash for StoreProviderTokenRequest
impl Hash for StoreProviderTokenRequest
Sourceimpl Message for StoreProviderTokenRequest
impl Message for StoreProviderTokenRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StoreProviderTokenRequest
impl PartialEq for StoreProviderTokenRequest
Sourcefn eq(&self, other: &StoreProviderTokenRequest) -> bool
fn eq(&self, other: &StoreProviderTokenRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for StoreProviderTokenRequest
impl StructuralPartialEq for StoreProviderTokenRequest