pub struct ThreadSummary {Show 40 fields
pub name: String,
pub base_state: Option<Vec<u8>>,
pub current_state: Option<Vec<u8>>,
pub path: Option<String>,
pub provider: Option<String>,
pub model: Option<String>,
pub coordination_status: String,
pub is_current: bool,
pub is_isolated: bool,
pub target_thread: Option<String>,
pub parent_thread: Option<String>,
pub task: Option<String>,
pub thread_mode: Option<String>,
pub thread_state: Option<String>,
pub freshness: Option<String>,
pub verification_summary: Option<ThreadVerificationSummary>,
pub confidence_summary: Option<ThreadConfidenceSummary>,
pub integration_policy_result: Option<ThreadIntegrationPolicy>,
pub harness: Option<String>,
pub thinking_level: Option<String>,
pub usage_summary: Option<UsageSummary>,
pub last_progress_at: Option<Timestamp>,
pub report_flush_state: Option<String>,
pub heddle_session_id: Option<String>,
pub attach_reason: Option<String>,
pub native_actor_key: Option<String>,
pub native_parent_actor_key: Option<String>,
pub probe_source: Option<String>,
pub probe_confidence: Option<f32>,
pub recommended_action: Option<String>,
pub blockers: Vec<String>,
pub thread_health: Option<String>,
pub promotion_suggested: bool,
pub child_threads: Vec<String>,
pub stack_depth: u32,
pub last_activity_at: Option<Timestamp>,
pub visibility: Option<String>,
pub changed_paths: Vec<String>,
pub impact_categories: Vec<String>,
pub heavy_impact_paths: Vec<String>,
}Fields
name: Stringbase_state: Option<Vec<u8>>current_state: Option<Vec<u8>>path: Option<String>provider: Option<String>model: Option<String>coordination_status: Stringis_current: boolis_isolated: booltarget_thread: Option<String>parent_thread: Option<String>task: Option<String>thread_mode: Option<String>thread_state: Option<String>freshness: Option<String>verification_summary: Option<ThreadVerificationSummary>confidence_summary: Option<ThreadConfidenceSummary>integration_policy_result: Option<ThreadIntegrationPolicy>harness: Option<String>thinking_level: Option<String>usage_summary: Option<UsageSummary>last_progress_at: Option<Timestamp>report_flush_state: Option<String>heddle_session_id: Option<String>attach_reason: Option<String>native_actor_key: Option<String>native_parent_actor_key: Option<String>probe_source: Option<String>probe_confidence: Option<f32>recommended_action: Option<String>blockers: Vec<String>thread_health: Option<String>promotion_suggested: boolchild_threads: Vec<String>stack_depth: u32last_activity_at: Option<Timestamp>visibility: Option<String>changed_paths: Vec<String>impact_categories: Vec<String>heavy_impact_paths: Vec<String>Implementations
Sourceimpl ThreadSummary
impl ThreadSummary
Sourcepub fn base_state(&self) -> &[u8] ⓘ
pub fn base_state(&self) -> &[u8] ⓘ
Returns the value of base_state, or the default value if base_state is unset.
Sourcepub fn current_state(&self) -> &[u8] ⓘ
pub fn current_state(&self) -> &[u8] ⓘ
Returns the value of current_state, or the default value if current_state is unset.
Sourcepub fn provider(&self) -> &str
pub fn provider(&self) -> &str
Returns the value of provider, or the default value if provider is unset.
Sourcepub fn model(&self) -> &str
pub fn model(&self) -> &str
Returns the value of model, or the default value if model is unset.
Sourcepub fn target_thread(&self) -> &str
pub fn target_thread(&self) -> &str
Returns the value of target_thread, or the default value if target_thread is unset.
Sourcepub fn parent_thread(&self) -> &str
pub fn parent_thread(&self) -> &str
Returns the value of parent_thread, or the default value if parent_thread is unset.
Sourcepub fn thread_mode(&self) -> &str
pub fn thread_mode(&self) -> &str
Returns the value of thread_mode, or the default value if thread_mode is unset.
Sourcepub fn thread_state(&self) -> &str
pub fn thread_state(&self) -> &str
Returns the value of thread_state, or the default value if thread_state is unset.
Sourcepub fn freshness(&self) -> &str
pub fn freshness(&self) -> &str
Returns the value of freshness, or the default value if freshness is unset.
Sourcepub fn harness(&self) -> &str
pub fn harness(&self) -> &str
Returns the value of harness, or the default value if harness is unset.
Sourcepub fn thinking_level(&self) -> &str
pub fn thinking_level(&self) -> &str
Returns the value of thinking_level, or the default value if thinking_level is unset.
Sourcepub fn report_flush_state(&self) -> &str
pub fn report_flush_state(&self) -> &str
Returns the value of report_flush_state, or the default value if report_flush_state is unset.
Sourcepub fn heddle_session_id(&self) -> &str
pub fn heddle_session_id(&self) -> &str
Returns the value of heddle_session_id, or the default value if heddle_session_id is unset.
Sourcepub fn attach_reason(&self) -> &str
pub fn attach_reason(&self) -> &str
Returns the value of attach_reason, or the default value if attach_reason is unset.
Sourcepub fn native_actor_key(&self) -> &str
pub fn native_actor_key(&self) -> &str
Returns the value of native_actor_key, or the default value if native_actor_key is unset.
Sourcepub fn native_parent_actor_key(&self) -> &str
pub fn native_parent_actor_key(&self) -> &str
Returns the value of native_parent_actor_key, or the default value if native_parent_actor_key is unset.
Sourcepub fn probe_source(&self) -> &str
pub fn probe_source(&self) -> &str
Returns the value of probe_source, or the default value if probe_source is unset.
Sourcepub fn probe_confidence(&self) -> f32
pub fn probe_confidence(&self) -> f32
Returns the value of probe_confidence, or the default value if probe_confidence is unset.
Sourcepub fn recommended_action(&self) -> &str
pub fn recommended_action(&self) -> &str
Returns the value of recommended_action, or the default value if recommended_action is unset.
Sourcepub fn thread_health(&self) -> &str
pub fn thread_health(&self) -> &str
Returns the value of thread_health, or the default value if thread_health is unset.
Sourcepub fn visibility(&self) -> &str
pub fn visibility(&self) -> &str
Returns the value of visibility, or the default value if visibility is unset.