Module metadata

Module metadata 

gRPC metadata handling.

gRPC metadata is a map of keys to values, similar to HTTP headers. This module provides types for working with metadata, including ASCII and binary values.

Key Concepts

Modules

errors
The metadata::errors module contains types for errors that can occur while handling gRPC custom metadata.

Structs

GetAll
A view to all values stored in a single entry.
Iter
MetadataMap entry iterator.
MetadataKey
Represents a custom metadata field name.
MetadataMap
A set of gRPC custom metadata entries.
MetadataValue
Represents a custom metadata field value.
ValueIter
An iterator of all values associated with a single metadata key.

Enums

Ascii
gRPC metadata values can be either ASCII strings or binary. Note that only visible ASCII characters (32-127) are permitted. This type should never be instantiated – in fact, it’s impossible to, because there are no variants to instantiate. Instead, it’s just used as a type parameter for MetadataKey and MetadataValue.
Binary
gRPC metadata values can be either ASCII strings or binary. This type should never be instantiated – in fact, it’s impossible to, because there are no variants to instantiate. Instead, it’s just used as a type parameter for MetadataKey and MetadataValue.
Key
Reference to a key in a MetadataMap. It can point to either an ascii or a binary (“*-bin”) key.
KeyAndValueRef
Reference to a key and an associated value in a MetadataMap. It can point to either an ascii or a binary (“*-bin”) key.

Type Aliases

AsciiMetadataKey
An ascii metadata key.
AsciiMetadataValue
An ascii metadata value.
BinaryMetadataKey
A binary metadata key.
BinaryMetadataValue
A binary metadata value.