[−][src]Struct grpc::ClientRequestSink
And interface to send messages when client request is streaming.
Methods
impl<Req: Send> ClientRequestSink<Req>[src]
pub fn poll(&mut self, cx: &mut Context) -> Poll<Result<(), StreamDead>>[src]
Poll for write availability.
When request is not polled, send_data
will be successful anyway, but client memory can overflow.
pub fn wait<'a>(
&'a mut self
) -> impl Future<Output = Result<(), StreamDead>> + 'a[src]
&'a mut self
) -> impl Future<Output = Result<(), StreamDead>> + 'a
Wait for buffer availability.
When request is not polled, send_data
will be successful anyway, but client memory can overflow.
pub fn send_data(&mut self, message: Req) -> Result<()>[src]
Send a message.
pub fn finish(&mut self) -> Result<()>[src]
Finish client request.
This is mandatory operation, if it is not called, client will reset the stream on drop.