gRPC metadata handling.
gRPC metadata is a map of keys to values, similar to HTTP headers. This module provides types for working with metadata, including ASCII and binary values.
Key Concepts
MetadataMap: The main struct for holding metadata.MetadataKey: Represents a key in the metadata map.MetadataValue: Represents a value in the metadata map.
Modules
- errors
- The metadata::errors module contains types for errors that can occur while handling gRPC custom metadata.
Structs
- GetAll
- A view to all values stored in a single entry.
- Iter
MetadataMapentry iterator.- Metadata
Key - Represents a custom metadata field name.
- Metadata
Map - A set of gRPC custom metadata entries.
- Metadata
Value - Represents a custom metadata field value.
- Value
Iter - An iterator of all values associated with a single metadata key.
Enums
- Ascii
- gRPC metadata values can be either ASCII strings or binary. Note that only
visible ASCII characters (32-127) are permitted.
This type should never be instantiated – in fact, it’s impossible
to, because there are no variants to instantiate. Instead, it’s just used as
a type parameter for
MetadataKeyandMetadataValue. - Binary
- gRPC metadata values can be either ASCII strings or binary.
This type should never be instantiated – in fact, it’s impossible
to, because there are no variants to instantiate. Instead, it’s just used as
a type parameter for
MetadataKeyandMetadataValue. - Key
- Reference to a key in a
MetadataMap. It can point to either an ascii or a binary (“*-bin”) key. - KeyAnd
Value Ref - Reference to a key and an associated value in a
MetadataMap. It can point to either an ascii or a binary (“*-bin”) key.
Type Aliases
- Ascii
Metadata Key - An ascii metadata key.
- Ascii
Metadata Value - An ascii metadata value.
- Binary
Metadata Key - A binary metadata key.
- Binary
Metadata Value - A binary metadata value.